@@ -5,8 +5,8 @@
 
 compartments <- function(metabolites){
   # Compartment main function
-  compartments <- unique(unlist(regmatches(metabolites, gregexpr("\\[[[:graph:]]+[[:punct:]\\]$", metabolites))))
+  compartments <- unique(unlist(regmatches(metabolites, gregexpr("\\[[[:alnum:]]*(\\_)?[[:alnum:]]*\\]$", metabolites))))
   compartments <- gsub("\\[","",compartments)
   compartments <- gsub("\\]","",compartments)
   return(compartments)
-}
+}
\ No newline at end of file
