@@ -8,16 +8,14 @@ orphan.reactants <- function(reactionList, byCompartment=FALSE){
   reactant <- unique(unlist(sapply(reactionList,reactants)))
   # Extract all products
   product <- unique(unlist(sapply(reactionList,products)))
-
+  # Possible candidates to be introduced into the system by exchange reactions or by adding more internal reactions.
+  orphan <- reactant[!(reactant%in%product)]
   if (byCompartment == TRUE){
-    # Identifies all reactants never produced in any reaction.
-    orphan <- reactant[!reactant%in%product]
     # Return orphans by compartment
-    sapply(compartments(orphan), function(comp){orphan[grep(comp,orphan)]}, simplify = FALSE)
+    sapply(compartments(orphan), function(comp){orphan[grep(paste0("\\[",comp,"\\]"),orphan)]}, simplify = FALSE)
   } else {
     # Return all reactants never produced in any reaction.
-    # Possible candidates to be introduced into the system by exchange reactions or by adding more internal reactions.
-    reactant[!reactant%in%product]
+    return(orphan)
   }
 }
 
