@@ -7,17 +7,16 @@ products <- function(reaction){
   # Identifies if stoichiometric reaction is not reversible. In this case:
   if (grepl("<=>",reaction)){
     products <- unlist(strsplit(reaction,"[[:blank:]]*<=>[[:blank:]]*"))
-  }else {
+  } else {
     products <- unlist(strsplit(reaction,"[[:blank:]]*=>[[:blank:]]*"))[2]
   }
 
   # Split independient reactants
-  products <- unlist(strsplit(products,"[[:blank:]]\\+[[:blank:]]"))
+  products <- unlist(strsplit(products,"[[:blank:]]+\\+[[:blank:]]+"))
   products <- gsub("^[[:blank:]]*","",products)
   products <- gsub("[[:blank:]]*$","",products)
   # Use a regex to extract stoichiometric coefficients and separate the metabolite name
   products <- gsub("^[[:digit:]][[:graph:]]*[[:blank:]]+","",products)
-  
+
   return(products[!is.na(products)])
 }
-
